<?php

namespace Property\Property\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Property\Property\Http\Requests\PropertyListsRequest;
use Property\Property\Interfaces\PropertyListsRepositoryInterface;
use Property\Property\Models\PropertyLists;

/**
 * Resource controller class for property_lists.
 */
class PropertyListsResourceController extends BaseController
{

    /**
     * Initialize property_lists resource controller.
     *
     * @param type PropertyListsRepositoryInterface $property_lists
     *
     * @return null
     */
    public function __construct(PropertyListsRepositoryInterface $property_lists)
    {
        parent::__construct();
        $this->repository = $property_lists;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Property\Property\Repositories\Criteria\PropertyListsResourceCriteria::class);
    }

    /**
     * Display a list of property_lists.
     *
     * @return Response
     */
    public function index(PropertyListsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Property\Property\Repositories\Presenter\PropertyListsPresenter::class)
                ->$function();
        }

        $property_lists = $this->repository->paginate();

        return $this->response->title(trans('property::property_lists.names'))
            ->view('property::property_lists.index', true)
            ->data(compact('property_lists', 'view'))
            ->output();
    }

    /**
     * Display property_lists.
     *
     * @param Request $request
     * @param Model   $property_lists
     *
     * @return Response
     */
    public function show(PropertyListsRequest $request, PropertyLists $property_lists)
    {

        if ($property_lists->exists) {
            $view = 'property::property_lists.show';
        } else {
            $view = 'property::property_lists.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('property::property_lists.name'))
            ->data(compact('property_lists'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new property_lists.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PropertyListsRequest $request)
    {

        $property_lists = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('property::property_lists.name')) 
            ->view('property::property_lists.create', true) 
            ->data(compact('property_lists'))
            ->output();
    }

    /**
     * Create new property_lists.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PropertyListsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $property_lists                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('property::property_lists.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('property/property_lists/' . $property_lists->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/property/property_lists'))
                ->redirect();
        }

    }

    /**
     * Show property_lists for editing.
     *
     * @param Request $request
     * @param Model   $property_lists
     *
     * @return Response
     */
    public function edit(PropertyListsRequest $request, PropertyLists $property_lists)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('property::property_lists.name'))
            ->view('property::property_lists.edit', true)
            ->data(compact('property_lists'))
            ->output();
    }

    /**
     * Update the property_lists.
     *
     * @param Request $request
     * @param Model   $property_lists
     *
     * @return Response
     */
    public function update(PropertyListsRequest $request, PropertyLists $property_lists)
    {
        try {
            $attributes = $request->all();

            $property_lists->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('property::property_lists.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('property/property_lists/' . $property_lists->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/property_lists/' . $property_lists->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the property_lists.
     *
     * @param Model   $property_lists
     *
     * @return Response
     */
    public function destroy(PropertyListsRequest $request, PropertyLists $property_lists)
    {
        try {

            $property_lists->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('property::property_lists.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('property/property_lists/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('property/property_lists/' . $property_lists->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple property_lists.
     *
     * @param Model   $property_lists
     *
     * @return Response
     */
    public function delete(PropertyListsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('property::property_lists.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('property/property_lists'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/property/property_lists'))
                ->redirect();
        }

    }

    /**
     * Restore deleted property_lists.
     *
     * @param Model   $property_lists
     *
     * @return Response
     */
    public function restore(PropertyListsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('property::property_lists.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/property/property_lists'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/property/property_lists/'))
                ->redirect();
        }

    }

}
